import os
import shutil
from .prompt import Prompt

import click


@click.group()
def main():
    pass


@main.command('min')
@click.option('--name', prompt='project name')
def proj_min(name):
    from jinja2 import Template

    here = os.path.abspath(os.path.dirname(__file__))
    template_dir = os.path.join(here, 'templates/min')

    proj_dir = './{}'.format(name)
    if os.path.isdir(proj_dir):
        Prompt.warn('ops, folder name has been used')
        return
    shutil.copytree(template_dir, './{}'.format(name))

    def replace_file(file):
        filename = os.path.split(file)[1]
        suffix = filename.split('.')[-1]
        if filename in ['.DS_Store']:
            return
        with open(file, 'r+') as f:
            template = Template(f.read())
            content = template.render(name=name) + '\n'
            f.seek(0)
            f.truncate()
            f.write(content)
        if suffix == 'j2':
            os.rename(file, file.replace('.j2', '.py'))

    def iter_dir(path):
        for cursor in os.listdir(path):
            cursor_abs = os.path.join(path, cursor)
            if os.path.isdir(cursor_abs):
                if cursor == '<proj>':
                    new_cursor_abs = os.path.join(path, name)
                    os.rename(cursor_abs, new_cursor_abs)
                    cursor_abs = new_cursor_abs
                iter_dir(cursor_abs)
            else:
                replace_file(cursor_abs)

    iter_dir(proj_dir)

    Prompt.success('project {} created, enjoy coding'.format(name))



import os
import sys
from shutil import rmtree

from setuptools import setup, Command

here = os.path.abspath(os.path.dirname(__file__))


class PublishCommand(Command):
    """Support setup.py publish."""

    description = 'Build and publish the package.'
    user_options = []

    @staticmethod
    def status(s):
        """Prints things in bold."""
        print('\033[1m{0}\033[0m'.format(s))

    def initialize_options(self):
        pass

    def finalize_options(self):
        pass

    def run(self):
        try:
            self.status('Removing previous builds…')
            rmtree(os.path.join(here, 'dist'))
        except OSError:
            pass

        self.status('Building Source and Wheel (universal) distribution…')
        os.system('{0} setup.py sdist bdist_wheel --universal'.format(
            sys.executable))

        self.status('Uploading the package to PyPi via Twine…')
        os.system('twine upload dist/*')

        sys.exit()


setup(
    name='tifa',
    version='0.1.2',
    packages=['tifa'],
    install_requires=['click'],
    include_package_data=True,
    entry_points={
        'console_scripts': [
            'tifa = tifa.cli:main'
        ]
    },
    url='https://github.com/wddwycc/tifa',
    license='MIT',
    author='duan',
    author_email='wddwyss@gmail.com',
    description='a modern flask scaffolding',
    classifiers=[
        'Development Status :: 3 - Alpha',
        'Intended Audience :: Developers',
        'Intended Audience :: System Administrators',
        'License :: OSI Approved :: ISC License (ISCL)',
        'Natural Language :: English',
        'Programming Language :: Python',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3 :: Only',
        'Programming Language :: Python :: 3.3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Topic :: Software Development',
        'Topic :: Software Development :: Code Generators',
    ],
    # $ setup.py publish support.
    cmdclass={
        'publish': PublishCommand,
    },
)



import click


def _tint(raw, color):
    return click.style(raw, fg=color)


class Prompt(object):
    @staticmethod
    def warn(raw):
        click.echo(_tint(raw, 'red'))

    @staticmethod
    def success(raw):
        click.echo(_tint(raw, 'green'))
